@@ -26,7 +26,7 @@ test_that("Class Accessor", {
   expect_equal(instance$x <- 2, 2)
   expect_equal(instance$x, 2)
   
-  removeClass("TestAcessor")
+  removeClass("TestAcessor", environment())
   
 })
 
